Skip to contents

Function to visually inspect values and colors of a specific zuericolors palette

Usage

view_zuericolors(palette)

Arguments

palette

Name of a specific palette. if it is not provided, all palettes are plotted.

Value

returns a plot of the requested color/palette

Examples

view_zuericolors("qual12")